@@ -19,11 +19,7 @@ import sys
 import traceback
 from functools import wraps
 
-from src.testproject.sdk.exceptions import SdkException
-
-from src.testproject.sdk.drivers.webdriver import Remote, Generic
-
-from src.testproject.sdk.drivers.webdriver.base import BaseDriver
+from src.testproject.helpers.activesessionhelper import get_active_driver_instance
 
 
 def report_assertion_errors(func=None, *, screenshot: bool = False):
@@ -42,14 +38,10 @@ def report_assertion_errors(func=None, *, screenshot: bool = False):
                 line_index = -1 if os.getenv("PYTEST_CURRENT_TEST") is not None else -2
 
                 # Depending on the unit testing framework we format the reported error differently
-                description = (
-                    ae.__repr__()
-                    if os.getenv("PYTEST_CURRENT_TEST") is not None
-                    else str(ae)
-                )
+                description = ae.__repr__() if os.getenv("PYTEST_CURRENT_TEST") is not None else str(ae)
 
                 _, line, function, text = tb_info[line_index]
-                driver = __get_active_driver_instance()
+                driver = get_active_driver_instance()
                 message = f"Assertion failed on line {line} in {function}"
                 description, message = __handle_step_report_details(description, message)
                 driver.report().step(
@@ -69,21 +61,6 @@ def report_assertion_errors(func=None, *, screenshot: bool = False):
     return _report_assertion_errors
 
 
-def __get_active_driver_instance():
-    """Get the current driver instance in use (BaseDriver, Remote or Generic) """
-    driver = BaseDriver.instance()
-    if driver is None:
-        driver = Remote.instance()
-        if driver is None:
-            driver = Generic.instance()
-            if driver is None:
-                raise SdkException(
-                    "No active driver instance found, so cannot report failed assertion"
-                )
-
-    return driver
-
-
 def __handle_step_report_details(description, message):
     """Handles the assertions description.
 
@@ -92,8 +69,8 @@ def __handle_step_report_details(description, message):
     """
     inner_description = re.search(r"AssertionError\('(.*)'\)", description)
     if inner_description:
-        inner_description = inner_description.group(1).replace('\\n', os.linesep).split(' + ')
-        description = 'Assertion failed {{' + inner_description[0] + '}}'
+        inner_description = inner_description.group(1).replace("\\n", os.linesep).split(" + ")
+        description = "Assertion failed {{" + inner_description[0] + "}}"
         if len(inner_description) > 1:
             message += os.linesep
             for line in inner_description[1:]:
