@@ -13,18 +13,25 @@
 # limitations under the License.
 
 import logging
+import os
+
+from selenium.webdriver.remote.webdriver import WebDriver as RemoteWebDriver
 
 from src.testproject.classes import StepSettings
 from src.testproject.enums import EnvironmentVariable
-from src.testproject.helpers import ReportHelper, LoggingHelper, ConfigHelper, AddonHelper
+from src.testproject.enums.report_type import ReportType
+from src.testproject.helpers import (
+    ReportHelper,
+    LoggingHelper,
+    ConfigHelper,
+    AddonHelper,
+)
 from src.testproject.rest import ReportSettings
 from src.testproject.sdk.exceptions import SdkException
 from src.testproject.sdk.internal.agent import AgentClient
 from src.testproject.sdk.internal.helpers import CustomCommandExecutor
 from src.testproject.sdk.internal.reporter import Reporter
 from src.testproject.sdk.internal.session import AgentSession
-from selenium.webdriver.remote.webdriver import WebDriver as RemoteWebDriver
-import os
 
 
 class BaseDriver(RemoteWebDriver):
@@ -33,9 +40,10 @@ class BaseDriver(RemoteWebDriver):
     Args:
         capabilities (dict): Automation session desired capabilities and options
         token (str): Developer token to be used to communicate with the Agent
-        projectname (str): Project name to report
-        jobname (str): Job name to report
+        project_name (str): Project name to report
+        job_name (str): Job name to report
         disable_reports (bool): set to True to disable all reporting (no report will be created on TestProject)
+        report_type (ReportType): Type of report to produce - cloud, local or both.
 
     Attributes:
         _agent_client (AgentClient): client responsible for communicating with the TestProject agent
@@ -52,9 +60,13 @@ class BaseDriver(RemoteWebDriver):
         self,
         capabilities: dict,
         token: str,
-        projectname: str,
-        jobname: str,
+        project_name: str,
+        job_name: str,
         disable_reports: bool,
+        report_type: ReportType,
+        agent_url: str,
+        report_name: str,
+        report_path: str,
     ):
 
         if BaseDriver.__instance is not None:
@@ -69,22 +81,23 @@ class BaseDriver(RemoteWebDriver):
 
         if disable_reports:
             # Setting the project and job name to empty strings will cause the Agent to not initialize a report
-            self._projectname = ""
-            self._jobname = ""
+            self._project_name = ""
+            self._job_name = ""
         else:
-            self._projectname = (
-                projectname
-                if projectname is not None
-                else ReportHelper.infer_project_name()
-            )
-            self._jobname = (
-                jobname if jobname is not None else ReportHelper.infer_job_name()
-            )
+            self._project_name = project_name if project_name is not None else ReportHelper.infer_project_name()
+
+            if job_name:
+                self._job_name = job_name
+            else:
+                self._job_name = ReportHelper.infer_job_name()
+                # Can update job name at runtime if not specified.
+                os.environ[EnvironmentVariable.TP_UPDATE_JOB_NAME.value] = "True"
 
         self._agent_client: AgentClient = AgentClient(
             token=self._token,
             capabilities=capabilities,
-            report_settings=ReportSettings(self._projectname, self._jobname),
+            agent_url=agent_url,
+            report_settings=ReportSettings(self._project_name, self._job_name, report_type, report_name, report_path),
         )
         self._agent_session: AgentSession = self._agent_client.agent_session
         self.w3c = True if self._agent_session.dialect == "W3C" else False
@@ -146,6 +159,17 @@ class BaseDriver(RemoteWebDriver):
         """
         return AddonHelper(self._agent_client, self.command_executor)
 
+    def pause(self, milliseconds: int):
+        self.command_executor.pause(milliseconds)
+
+    def update_job_name(self, job_name):
+        """Updates the job name of the execution during runtime
+
+        Args:
+            job_name (str): updated job name to set for the execution.
+        """
+        self._agent_client.update_job_name(job_name=job_name)
+
     def quit(self):
         """Quits the driver and stops the session with the Agent, cleaning up after itself"""
         # Report any left over driver command reports
