@@ -40,6 +40,9 @@ class Firefox(BaseDriver):
         job_name: str = None,
         disable_reports: bool = False,
         report_type: ReportType = ReportType.CLOUD_AND_LOCAL,
+        agent_url: str = None,
+        report_name: str = None,
+        report_path: str = None,
     ):
 
         # If no options or capabilities are specified at all, use default FirefoxOptions
@@ -56,4 +59,7 @@ class Firefox(BaseDriver):
             job_name=job_name,
             disable_reports=disable_reports,
             report_type=report_type,
+            agent_url=agent_url,
+            report_name=report_name,
+            report_path=report_path,
         )
